Changelog
=========

1.5 - 2022-02-27
----------------

* Add Python 3.8-3.10 to tox.ini. Remove old Python versions.
  [stefan]

* Replace deprecated ``python setup.py test`` in tox.ini.
  [stefan]

* Remove deprecated ``test_suite`` from setup.py.
  [stefan]

* Move lexer into ``pygments_openssl`` namespace.
  [stefan]

* Move metadata to setup.cfg and add a pyproject.toml file.
  [stefan]

* Include tests in sdist but not in wheel.
  [stefan]

* Support new ``.pragma`` and ``.include`` directives.
  [stefan]

* Pygments 2.11 whitespace token modernization.
  [stefan]

1.4 - 2019-01-25
----------------

* Add MANIFEST.in.
  [stefan]

* Release as wheel.
  [stefan]

1.3 - 2017-02-05
----------------

* Add a LICENSE file.
  [stefan]

* Add a test suite and fix two minor whitespace lexing issues.
  [stefan]

1.2 - 2013-11-21
----------------

* Update documentation.
  [stefan]

1.1 - 2012-10-12
----------------

* Detect and color line continuations.
  [stefan]

1.0 - 2012-10-10
----------------

* Initial release.
  [stefan]
